{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Annotate Bam Stats to Somatic Vcf Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/normal_id",
                    "type": "string"
                },
                {
                    "id": "#main/tumor_id",
                    "type": "string"
                },
                {
                    "id": "#main/normal_bam",
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#main/tumor_bam",
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#main/reference",
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        "^.dict"
                    ]
                },
                {
                    "id": "#main/vcf",
                    "type": "File"
                },
                {
                    "id": "#main/addbamstats_type",
                    "doc": "must be either germline or somatic",
                    "type": "string",
                    "default": "somatic"
                }
            ],
            "steps": [
                {
                    "id": "#main/tumor",
                    "in": [
                        {
                            "id": "#main/tumor/vcf",
                            "source": "#main/vcf"
                        },
                        {
                            "id": "#main/tumor/bam",
                            "source": "#main/tumor_bam"
                        },
                        {
                            "id": "#main/tumor/reference",
                            "source": "#main/reference"
                        }
                    ],
                    "run": "#samtools_mpileup_subpipeline.cwl",
                    "out": [
                        {
                            "id": "#main/tumor/out"
                        }
                    ]
                },
                {
                    "id": "#main/normal",
                    "in": [
                        {
                            "id": "#main/normal/vcf",
                            "source": "#main/vcf"
                        },
                        {
                            "id": "#main/normal/bam",
                            "source": "#main/normal_bam"
                        },
                        {
                            "id": "#main/normal/reference",
                            "source": "#main/reference"
                        }
                    ],
                    "run": "#samtools_mpileup_subpipeline.cwl",
                    "out": [
                        {
                            "id": "#main/normal/out"
                        }
                    ]
                },
                {
                    "id": "#main/addbamstats",
                    "label": "Add Bam Statistics to Vcf",
                    "in": [
                        {
                            "id": "#main/addbamstats/normalMpileup",
                            "source": "#main/normal/out"
                        },
                        {
                            "id": "#main/addbamstats/tumorMpileup",
                            "source": "#main/tumor/out"
                        },
                        {
                            "id": "#main/addbamstats/normalID",
                            "source": "#main/normal_id"
                        },
                        {
                            "id": "#main/addbamstats/tumorID",
                            "source": "#main/tumor_id"
                        },
                        {
                            "id": "#main/addbamstats/inputVcf",
                            "source": "#main/vcf"
                        },
                        {
                            "id": "#main/addbamstats/type",
                            "source": "#main/addbamstats_type"
                        }
                    ],
                    "run": "#addBamStats_0_0_7.cwl",
                    "out": [
                        {
                            "id": "#main/addbamstats/out"
                        }
                    ]
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "id": "#main/out",
                    "type": "File",
                    "outputSource": "#main/addbamstats/out"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "SamTools: Mpileup",
            "doc": "Generate text pileup output for one or multiple BAM files. Each input file produces a separate group of pileup columns in the output.\n\nSamtools mpileup can still produce VCF and BCF output (with -g or -u), but this feature is deprecated and will be removed in a future release. Please use bcftools mpileup for this instead. (Documentation on the deprecated options has been removed from this manual page, but older versions are available online at <http://www.htslib.org/doc/>.)\n\nNote that there are two orthogonal ways to specify locations in the input file; via -r region and -l file. The former uses (and requires) an index to do random access while the latter streams through the file contents filtering out the specified regions, requiring no index. The two may be used in conjunction. For example a BED file containing locations of genes in chromosome 20 could be specified using -r 20 -l chr20.bed, meaning that the index is used to find chromosome 20 and then it is filtered for the regions listed in the bed file.",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h8571acd_11"
                }
            ],
            "inputs": [
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/illuminaEncoding",
                    "label": "illuminaEncoding",
                    "doc": "Assume the quality is in the Illumina 1.3+ encoding.",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--illumina1.3+"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/countOrphans",
                    "label": "countOrphans",
                    "doc": "do not discard anomalous read pairs",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--count-orphans"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/noBAQ",
                    "label": "noBAQ",
                    "doc": "disable BAQ (per-Base Alignment Quality)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--no-BAQ"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/adjustMQ",
                    "label": "adjustMQ",
                    "doc": "adjust mapping quality; recommended:50, disable:0 [0]",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--adjust-MQ"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/maxDepth",
                    "label": "maxDepth",
                    "doc": "max per-file depth; avoids excessive memory usage [8000]",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--max-depth"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/redoBAQ",
                    "label": "redoBAQ",
                    "doc": "recalculate BAQ on the fly, ignore existing BQs",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--redo-BAQ"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/fastaRef",
                    "label": "fastaRef",
                    "doc": " skip unlisted positions (chr pos) or regions (BED)",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--fasta-ref"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/excludeRG",
                    "label": "excludeRG",
                    "doc": "exclude read groups listed in FILE",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--exclude-RG"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/positions",
                    "label": "positions",
                    "doc": "skip unlisted positions (chr pos) or regions (BED)",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--positions"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/minBQ",
                    "label": "minBQ",
                    "doc": "Minimum base quality for a base to be considered [13]",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--min-BQ"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/minMQ",
                    "label": "minMQ",
                    "doc": "skip alignments with mapQ smaller than INT [0]",
                    "type": [
                        "int",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--min-MQ"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/region",
                    "label": "region",
                    "doc": "region in which pileup is generated",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--region"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/ignoreRG",
                    "label": "ignoreRG",
                    "doc": "ignore RG tags (one BAM = one sample)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--ignore-RG"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/inclFlags",
                    "label": "inclFlags",
                    "doc": "required flags: skip reads with mask bits unset []",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--incl-flags"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/exclFlags",
                    "label": "exclFlags",
                    "doc": "filter flags: skip reads with mask bits set [UNMAP,SECONDARY,QCFAIL,DUP]",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--excl-flags"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/ignoreOverlaps",
                    "label": "ignoreOverlaps",
                    "doc": "disable read-pair overlap detection",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--ignore-overlaps"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/outputBP",
                    "label": "outputBP",
                    "doc": "output base positions on reads",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--output-BP"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/outputMQ",
                    "label": "outputMQ",
                    "doc": "output mapping quality",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--output-MQ"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/outputQNAME",
                    "label": "outputQNAME",
                    "doc": "output read names",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--output-QNAME"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/allPositions",
                    "label": "allPositions",
                    "doc": "output all positions (including zero depth)",
                    "type": [
                        "boolean",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/absolutelyAllPositions",
                    "label": "absolutelyAllPositions",
                    "doc": "output absolutely all positions, including unused ref. sequences",
                    "type": [
                        "boolean",
                        "null"
                    ]
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/reference",
                    "label": "reference",
                    "doc": "Reference sequence FASTA FILE [null]",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--reference"
                    }
                },
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/bam",
                    "label": "bam",
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 10
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#SamToolsMpileup_1_9_0.cwl/SamToolsMpileup/out",
                    "label": "out",
                    "type": "File",
                    "outputBinding": {
                        "glob": "_stdout"
                    }
                }
            ],
            "stdout": "_stdout",
            "stderr": "_stderr",
            "baseCommand": [
                "samtools",
                "mpileup"
            ],
            "arguments": [],
            "id": "#SamToolsMpileup_1_9_0.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Add Bam Statistics to Vcf",
            "doc": "usage: add_bam_stats.py [-h] -i I -o O --type {germline,somatic}\n                        [--mpileup MPILEUP] [--normal_mpileup NORMAL_MPILEUP]\n                        [--tumor_mpileup TUMOR_MPILEUP]\n                        [--normal_id NORMAL_ID] [--tumor_id TUMOR_ID]\n\nGet stats from bam file and write to vcf\n\nrequired arguments:\n  -i I                  input vcf\n  -o O                  output vcf\n  --type {germline,somatic}\n                        must be either germline or somatic\n  --mpileup MPILEUP     mpileup file extracted from bam file\n  --normal_mpileup NORMAL_MPILEUP\n                        mpileup file extracted from the normal sample bam,\n                        required if input is somatic vcf\n  --tumor_mpileup TUMOR_MPILEUP\n                        mpileup file extracted from the tumor sample, required\n                        if input is somatic vcf\n  --normal_id NORMAL_ID\n                        Normal sample id, required if input is somatic vcf\n  --tumor_id TUMOR_ID   Tumor sample id, required if input is somatic vcf\n\noptional arguments:\n  -h, --help            show this help message and exit\n        ",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "michaelfranklin/pmacutil:0.0.7"
                }
            ],
            "inputs": [
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/mpileup",
                    "label": "mpileup",
                    "doc": "mpileup file extracted from bam file",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--mpileup"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/normalMpileup",
                    "label": "normalMpileup",
                    "doc": "mpileup file extracted from the normal sample bam, required if input is somatic vcf",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--normal_mpileup"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/tumorMpileup",
                    "label": "tumorMpileup",
                    "doc": "mpileup file extracted from the tumor sample bam, required if input is somatic vcf",
                    "type": [
                        "File",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--tumor_mpileup"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/normalID",
                    "label": "normalID",
                    "doc": "normal sample id, required if input is somatic vcf",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--normal_id"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/tumorID",
                    "label": "tumorID",
                    "doc": "tumor sample id, required if input is somatic vcf",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "--tumor_id"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/inputVcf",
                    "label": "inputVcf",
                    "doc": "input vcf",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/outputFilename",
                    "label": "outputFilename",
                    "doc": "output vcf name",
                    "type": [
                        "string",
                        "null"
                    ],
                    "default": "generated.addbamstats.vcf",
                    "inputBinding": {
                        "prefix": "-o"
                    }
                },
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/type",
                    "label": "type",
                    "doc": "must be either germline or somatic",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--type"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#addBamStats_0_0_7.cwl/addBamStats/out",
                    "label": "out",
                    "type": "File",
                    "outputBinding": {
                        "glob": "generated.addbamstats.vcf",
                        "loadContents": false
                    }
                }
            ],
            "stdout": "_stdout",
            "stderr": "_stderr",
            "baseCommand": "add_bam_stats.py",
            "arguments": [],
            "id": "#addBamStats_0_0_7.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/vcf",
                    "type": "File"
                },
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/bam",
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ]
                },
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/reference",
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa",
                        "^.dict"
                    ]
                },
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_countOrphans",
                    "doc": "do not discard anomalous read pairs",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_noBAQ",
                    "doc": "disable BAQ (per-Base Alignment Quality)",
                    "type": "boolean",
                    "default": true
                },
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_minBQ",
                    "doc": "Minimum base quality for a base to be considered [13]",
                    "type": "int",
                    "default": 0
                },
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_maxDepth",
                    "doc": "max per-file depth; avoids excessive memory usage [8000]",
                    "type": "int",
                    "default": 10000
                }
            ],
            "outputs": [
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/out",
                    "type": "File",
                    "outputSource": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/out"
                }
            ],
            "steps": [
                {
                    "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup",
                    "label": "SamTools: Mpileup",
                    "in": [
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/countOrphans",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_countOrphans"
                        },
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/noBAQ",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_noBAQ"
                        },
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/maxDepth",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_maxDepth"
                        },
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/positions",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/vcf"
                        },
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/minBQ",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup_minBQ"
                        },
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/reference",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/reference"
                        },
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/bam",
                            "source": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/bam"
                        }
                    ],
                    "run": "#SamToolsMpileup_1_9_0.cwl",
                    "out": [
                        {
                            "id": "#samtools_mpileup_subpipeline.cwl/samtools_mpileup_subpipeline/samtools_mpileup/out"
                        }
                    ]
                }
            ],
            "id": "#samtools_mpileup_subpipeline.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
